# PKRDPNT

La libreria (Pokémon random print) que sirve
para generar un pokémon aleatorio

## Instalación
Para poder instalar la libreria; tienes que usar `pip install PKRDPNT`
# Uso
Genera un pokemon aleatorio y lo muestra al usuario
## Autor: Christopher Ruiz Molina